==> sparktool-3.0.8.tar.gz: sparktool-3.0.8/sparktool/sparkvar.py <==
savejson = '''
{
    "id": {id},
    "uuid": "{uuid}",
    "name": "{name}",
    "description": "",
    "type": "query-impala",
    "initialType": "impala",
    "coordinatorUuid": null,
    "isHistory": false,
    "isManaged": false,
    "parentSavedQueryUuid": null,
    "isSaved": false,
    "onSuccessUrl": null,
    "pubSubUrl": null,
    "isPresentationModeDefault": false,
    "isPresentationMode": false,
    "presentationSnippets": {},
    "isHidingCode": false,
    "snippets": [
        {
            "id": "4a035dad-7fd7-ea75-9f01-fb8393be2553",
            "name": "",
            "type": "impala",
            "isBatchable": true,
            "aceCursorPosition": {
                "row": 0,
                "column": 0
            },
            "errors": [],
            "aceErrorsHolder": [],
            "aceWarningsHolder": [],
            "aceErrors": [],
            "aceWarnings": [],
            "editorMode": true,
            "dbSelectionVisible": false,
            "isSqlDialect": true,
            "database": "default",
            "currentQueryTab": "savedQueries",
            "pinnedContextTabs": [],
            "loadingQueries": false,
            "queriesHasErrors": false,
            "queriesCurrentPage": 1,
            "queriesTotalPages": 1,
            "queriesFilter": "",
            "queriesFilterVisible": false,
            "statementType": "text",
            "statementTypes": [
                "text",
                "file"
            ],
            "statementPath": "",
            "externalStatementLoaded": false,
            "associatedDocumentLoading": true,
            "associatedDocumentUuid": null,
            "statement_raw": "{sql}",
            "statementsList": [
                "{sql}"
            ],
            "aceSize": 100,
            "status": "ready",
            "statusForButtons": "executed",
            "properties": {
                "settings": []
            },
            "viewSettings": {
                "placeHolder": "Example: SELECT * FROM tablename, or press CTRL + space",
                "sqlDialect": true
            },
            "variables": [],
            "hasCurlyBracketParameters": true,
            "variableNames": [],
            "variableValues": {},
            "statement": "{sql}",
            "result": {
                "id": "10b9b4c9-fea3-1c19-7c1b-1edd3a3d3b67",
                "type": "table",
                "hasResultset": true,
                "handle": {},
                "meta": [],
                "rows": null,
                "hasMore": false,
                "statement_id": 0,
                "statement_range": {
                    "start": {
                        "row": 0,
                        "column": 0
                    },
                    "end": {
                        "row": 0,
                        "column": 0
                    }
                },
                "statements_count": 1,
                "previous_statement_hash": null,
                "metaFilter": {
                    "query": "",
                    "facets": {},
                    "text": []
                },
                "isMetaFilterVisible": false,
                "filteredMetaChecked": true,
                "filteredMeta": [],
                "fetchedOnce": false,
                "startTime": "2020-01-29T14:44:00.831Z",
                "endTime": "2020-01-29T14:44:00.831Z",
                "executionTime": 0,
                "data": [],
                "explanation": "",
                "logs": "",
                "logLines": 0,
                "hasSomeResults": false
            },
            "showGrid": true,
            "showChart": false,
            "showLogs": true,
            "progress": 0,
            "jobs": [],
            "isLoading": false,
            "resultsKlass": "results impala",
            "errorsKlass": "results impala alert alert-error",
            "is_redacted": false,
            "chartType": "bars",
            "chartSorting": "none",
            "chartScatterGroup": null,
            "chartScatterSize": null,
            "chartScope": "world",
            "chartTimelineType": "bar",
            "chartLimits": [
                5,
                10,
                25,
                50,
                100
            ],
            "chartLimit": null,
            "chartX": null,
            "chartXPivot": null,
            "chartYSingle": null,
            "chartYMulti": [],
            "chartData": [],
            "chartMapType": "marker",
            "chartMapLabel": null,
            "chartMapHeat": null,
            "hasDataForChart": false,
            "previousChartOptions": {},
            "isResultSettingsVisible": false,
            "settingsVisible": false,
            "checkStatusTimeout": null,
            "topRisk": null,
            "suggestion": "",
            "hasSuggestion": null,
            "compatibilityCheckRunning": false,
            "compatibilitySourcePlatform": "impala",
            "compatibilitySourcePlatforms": [
                {
                    "name": "Teradata",
                    "value": "teradata"
                },
                {
                    "name": "Oracle",
                    "value": "oracle"
                },
                {
                    "name": "Netezza",
                    "value": "netezza"
                },
                {
                    "name": "Impala",
                    "value": "impala"
                },
                {
                    "name": "Hive",
                    "value": "hive"
                },
                {
                    "name": "DB2",
                    "value": "db2"
                },
                {
                    "name": "Greenplum",
                    "value": "greenplum"
                },
                {
                    "name": "MySQL",
                    "value": "mysql"
                },
                {
                    "name": "PostgreSQL",
                    "value": "postgresql"
                },
                {
                    "name": "Informix",
                    "value": "informix"
                },
                {
                    "name": "SQL Server",
                    "value": "sqlserver"
                },
                {
                    "name": "Sybase",
                    "value": "sybase"
                },
                {
                    "name": "Access",
                    "value": "access"
                },
                {
                    "name": "Firebird",
                    "value": "firebird"
                },
                {
                    "name": "ANSISQL",
                    "value": "ansisql"
                },
                {
                    "name": "Generic",
                    "value": "generic"
                }
            ],
            "compatibilityTargetPlatform": "impala",
            "compatibilityTargetPlatforms": [
                {
                    "name": "Impala",
                    "value": "impala"
                },
                {
                    "name": "Hive",
                    "value": "hive"
                }
            ],
            "showOptimizer": false,
            "wasBatchExecuted": false,
            "isReady": true,
            "lastExecuted": 0,
            "lastAceSelectionRowOffset": 0,
            "executingBlockingOperation": null,
            "showLongOperationWarning": false,
            "formatEnabled": true,
            "isFetchingData": false,
            "isCanceling": false
        }
    ],
    "selectedSnippet": "impala",
    "creatingSessionLocks": [],
    "sessions": [
        {
            "type": "impala",
            "properties": [
                {
                    "nice_name": "Settings",
                    "multiple": true,
                    "key": "settings",
                    "help_text": "Impala configuration properties.",
                    "defaultValue": [],
                    "type": "settings",
                    "options": [
                        "debug_action",
                        "explain_level",
                        "mem_limit",
                        "optimize_partition_key_scans",
                        "query_timeout_s",
                        "request_pool"
                    ],
                    "value": []
                }
            ],
            "http_addr": "http://prod-hadoop-23.homecredit.cn:25000",
            "reuse_session": true,
            "session_id": "33422f284ecbf4e8:7dc482e902499d8d",
            "id": 107443
        }
    ],
    "directoryUuid": "",
    "dependentsCoordinator": [],
    "historyFilter": "",
    "historyFilterVisible": false,
    "loadingHistory": false,
    "historyInitialHeight": 1680,
    "forceHistoryInitialHeight": false,
    "historyCurrentPage": 1,
    "historyTotalPages": 35,
    "schedulerViewModel": null,
    "schedulerViewModelIsLoaded": false,
    "isBatchable": true,
    "isExecutingAll": false,
    "executingAllIndex": 0,
    "retryModalConfirm": null,
    "retryModalCancel": null,
    "unloaded": false,
    "updateHistoryFailed": false,
    "viewSchedulerId": "",
    "loadingScheduler": false
}
'''

==> sparktool-3.1.1.tar.gz: sparktool-3.1.1/sparktool/sparkvar.py <==
savejson = '''
{
    "id": {id},
    "uuid": "{uuid}",
    "name": "{name}",
    "description": "",
    "type": "query-impala",
    "initialType": "impala",
    "coordinatorUuid": null,
    "isHistory": false,
    "isManaged": false,
    "parentSavedQueryUuid": null,
    "isSaved": false,
    "onSuccessUrl": null,
    "pubSubUrl": null,
    "isPresentationModeDefault": false,
    "isPresentationMode": false,
    "presentationSnippets": {},
    "isHidingCode": false,
    "snippets": [
        {
            "id": "4a035dad-7fd7-ea75-9f01-fb8393be2553",
            "name": "",
            "type": "impala",
            "isBatchable": true,
            "aceCursorPosition": {
                "row": 0,
                "column": 0
            },
            "errors": [],
            "aceErrorsHolder": [],
            "aceWarningsHolder": [],
            "aceErrors": [],
            "aceWarnings": [],
            "editorMode": true,
            "dbSelectionVisible": false,
            "isSqlDialect": true,
            "database": "default",
            "currentQueryTab": "savedQueries",
            "pinnedContextTabs": [],
            "loadingQueries": false,
            "queriesHasErrors": false,
            "queriesCurrentPage": 1,
            "queriesTotalPages": 1,
            "queriesFilter": "",
            "queriesFilterVisible": false,
            "statementType": "text",
            "statementTypes": [
                "text",
                "file"
            ],
            "statementPath": "",
            "externalStatementLoaded": false,
            "associatedDocumentLoading": true,
            "associatedDocumentUuid": null,
            "statement_raw": "{sqlraw}",
            "statementsList": [
                {sqllist}
            ],
            "aceSize": 100,
            "status": "ready",
            "statusForButtons": "executed",
            "properties": {
                "settings": []
            },
            "viewSettings": {
                "placeHolder": "Example: SELECT * FROM tablename, or press CTRL + space",
                "sqlDialect": true
            },
            "variables": [],
            "hasCurlyBracketParameters": true,
            "variableNames": [],
            "variableValues": {},
            "statement": "{sqllast}",
            "result": {
                "id": "10b9b4c9-fea3-1c19-7c1b-1edd3a3d3b67",
                "type": "table",
                "hasResultset": true,
                "handle": {},
                "meta": [],
                "rows": null,
                "hasMore": false,
                "statement_id": 0,
                "statement_range": {
                    "start": {
                        "row": 0,
                        "column": 0
                    },
                    "end": {
                        "row": 0,
                        "column": 0
                    }
                },
                "statements_count": 1,
                "previous_statement_hash": null,
                "metaFilter": {
                    "query": "",
                    "facets": {},
                    "text": []
                },
                "isMetaFilterVisible": false,
                "filteredMetaChecked": true,
                "filteredMeta": [],
                "fetchedOnce": false,
                "startTime": "2020-01-29T14:44:00.831Z",
                "endTime": "2020-01-29T14:44:00.831Z",
                "executionTime": 0,
                "data": [],
                "explanation": "",
                "logs": "",
                "logLines": 0,
                "hasSomeResults": false
            },
            "showGrid": true,
            "showChart": false,
            "showLogs": true,
            "progress": 0,
            "jobs": [],
            "isLoading": false,
            "resultsKlass": "results impala",
            "errorsKlass": "results impala alert alert-error",
            "is_redacted": false,
            "chartType": "bars",
            "chartSorting": "none",
            "chartScatterGroup": null,
            "chartScatterSize": null,
            "chartScope": "world",
            "chartTimelineType": "bar",
            "chartLimits": [
                5,
                10,
                25,
                50,
                100
            ],
            "chartLimit": null,
            "chartX": null,
            "chartXPivot": null,
            "chartYSingle": null,
            "chartYMulti": [],
            "chartData": [],
            "chartMapType": "marker",
            "chartMapLabel": null,
            "chartMapHeat": null,
            "hasDataForChart": false,
            "previousChartOptions": {},
            "isResultSettingsVisible": false,
            "settingsVisible": false,
            "checkStatusTimeout": null,
            "topRisk": null,
            "suggestion": "",
            "hasSuggestion": null,
            "compatibilityCheckRunning": false,
            "compatibilitySourcePlatform": "impala",
            "compatibilitySourcePlatforms": [
                {
                    "name": "Teradata",
                    "value": "teradata"
                },
                {
                    "name": "Oracle",
                    "value": "oracle"
                },
                {
                    "name": "Netezza",
                    "value": "netezza"
                },
                {
                    "name": "Impala",
                    "value": "impala"
                },
                {
                    "name": "Hive",
                    "value": "hive"
                },
                {
                    "name": "DB2",
                    "value": "db2"
                },
                {
                    "name": "Greenplum",
                    "value": "greenplum"
                },
                {
                    "name": "MySQL",
                    "value": "mysql"
                },
                {
                    "name": "PostgreSQL",
                    "value": "postgresql"
                },
                {
                    "name": "Informix",
                    "value": "informix"
                },
                {
                    "name": "SQL Server",
                    "value": "sqlserver"
                },
                {
                    "name": "Sybase",
                    "value": "sybase"
                },
                {
                    "name": "Access",
                    "value": "access"
                },
                {
                    "name": "Firebird",
                    "value": "firebird"
                },
                {
                    "name": "ANSISQL",
                    "value": "ansisql"
                },
                {
                    "name": "Generic",
                    "value": "generic"
                }
            ],
            "compatibilityTargetPlatform": "impala",
            "compatibilityTargetPlatforms": [
                {
                    "name": "Impala",
                    "value": "impala"
                },
                {
                    "name": "Hive",
                    "value": "hive"
                }
            ],
            "showOptimizer": false,
            "wasBatchExecuted": false,
            "isReady": true,
            "lastExecuted": 0,
            "lastAceSelectionRowOffset": 0,
            "executingBlockingOperation": null,
            "showLongOperationWarning": false,
            "formatEnabled": true,
            "isFetchingData": false,
            "isCanceling": false
        }
    ],
    "selectedSnippet": "impala",
    "creatingSessionLocks": [],
    "sessions": [
        {
            "type": "impala",
            "properties": [
                {
                    "nice_name": "Settings",
                    "multiple": true,
                    "key": "settings",
                    "help_text": "Impala configuration properties.",
                    "defaultValue": [],
                    "type": "settings",
                    "options": [
                        "debug_action",
                        "explain_level",
                        "mem_limit",
                        "optimize_partition_key_scans",
                        "query_timeout_s",
                        "request_pool"
                    ],
                    "value": []
                }
            ],
            "http_addr": "http://prod-hadoop-23.homecredit.cn:25000",
            "reuse_session": true,
            "session_id": "33422f284ecbf4e8:7dc482e902499d8d",
            "id": 107443
        }
    ],
    "directoryUuid": "",
    "dependentsCoordinator": [],
    "historyFilter": "",
    "historyFilterVisible": false,
    "loadingHistory": false,
    "historyInitialHeight": 1680,
    "forceHistoryInitialHeight": false,
    "historyCurrentPage": 1,
    "historyTotalPages": 35,
    "schedulerViewModel": null,
    "schedulerViewModelIsLoaded": false,
    "isBatchable": true,
    "isExecutingAll": false,
    "executingAllIndex": 0,
    "retryModalConfirm": null,
    "retryModalCancel": null,
    "unloaded": false,
    "updateHistoryFailed": false,
    "viewSchedulerId": "",
    "loadingScheduler": false
}
'''
